CustomStateBuilder class

A custom builder for generating Bloc state extensions.

This builder processes files ending with '_cubit.dart' or '_bloc.dart' and generates corresponding state extension files.

Constructors

CustomStateBuilder()

Properties

buildExtensions Map<String, List<String>>
Defines the input and output file extensions for the builder.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Builds the state extensions for the given buildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited